@@ -1,7 +1,5 @@
 package Object::RateLimiter;
-{
-  $Object::RateLimiter::VERSION = '1.001002';
-}
+$Object::RateLimiter::VERSION = '1.001003';
 use strict; use warnings FATAL => 'all';
 
 use Carp 'confess';
@@ -36,10 +34,8 @@ around new => sub {
 
 sub clone {
   my ($self, %params) = @_;
-  $params{events} = $self->events
-    unless defined $params{events};
-  $params{seconds} = $self->seconds
-    unless defined $params{seconds};
+  $params{events}  = $self->events  unless defined $params{events};
+  $params{seconds} = $self->seconds unless defined $params{seconds};
 
   my $cloned = $self->new(%params);
   if (my $currentq = $self->_queue) {
@@ -62,7 +58,7 @@ sub delay {
       + ( $ev_count * $self->seconds / $ev_limit ) 
     ) - time;
 
-    $delayed > 0 ? return $delayed : $thisq->shift
+    $delayed > 0 ? return($delayed) : $thisq->shift
   }
 
   $thisq->push( time );
@@ -75,7 +71,8 @@ sub clear { $_[0]->[QUEUE] = undef; 1 }
 
 sub expire {
   my ($self) = @_;
-  $self->is_expired ? $self->clear : ()
+  return unless $self->is_expired;
+  $self->clear
 }
 
 sub is_expired {
@@ -83,10 +80,18 @@ sub is_expired {
   my $thisq  = $self->_queue   || return;
   my $latest = $thisq->get(-1) || return;
 
-  time - $latest > $self->seconds ? 1 : ()
+  time - $latest > $self->seconds
 }
 
-1;
+print
+  qq[<avenj> it's not\n],
+  qq[<JCW> What's not what?\n],
+  qq[<Capn_Refsmmat> I always thought that\n],
+  qq[<JCW> Thought what?  :o\n],
+  qq[<Capn_Refsmmat> well, I've always had this vague feeling of\n],
+  qq[<JCW> Heh, you sound like seuss.\n],
+  qq[<Capn_Refsmmat> I'm very by your remark\n]
+unless caller; 1;
 
 =pod
 
@@ -117,11 +122,9 @@ Object::RateLimiter - A flood control (rate limiter) object
     if (my $delay = $ctrl->delay) {
       # Delayed $delay (fractional) seconds.
       # (You might want Time::HiRes::sleep, or yield to event loop, etc)
-      sleep $delay;
-    } else {
-      # No delay.
-      print $some_item->()
+      sleep $delay
     }
+    print $some_item->()
   }
 
   # Clear the event history if it's stale:
@@ -169,7 +172,7 @@ Constructs a new rate-limiter with a clean event history.
 
   $ctrl->clear;
 
-Clears the event history. Always returns true.
+Clear the event history.
 
 =head2 clone
 
@@ -213,8 +216,8 @@ Clears the event history if L</is_expired> is true.
 
 Returns true if L</clear> was called.
 
-You're not required to call C<expire()>, but it can be useful to save a little
-memory (a 10 event history uses about 1kb here).
+(You're not required to call C<expire()>, but it can be useful to save a
+little memory.)
 
 =head2 is_expired
 
